This is an open-source Python package used in my Ph.D project to analyse and visualise cGENIE model output (mostly in netCDF format).


## Main features 🐛

### unit system
### visualisation based on Matplotlib
- Map
- Ocean Transection Contour 
- Taylor diagram

### chemistry system
### ocean basin detection


## Installation 🙂

```bash
python3 -m pip install -i https://test.pypi.org/simple/ cgeniepy==0.4.0
```

## TODO 🚩

- [] Documentation
- [] Examples
- [] Unit Tests
